@@ -19,8 +19,6 @@ class TimestreamLoader(TimestreamReader):
         table_name: str = None,
         session: boto3.Session = None,
         current_time_ms: int = None,
-        max_batch_size: int = None,
-        min_common_dimensions: int = None,
         logger: logging.Logger = None
     ):
         assert database_name, 'Must specify a database_name'
@@ -28,9 +26,7 @@ class TimestreamLoader(TimestreamReader):
         super().__init__(session, current_time_ms, logger)
         self.__database_name = database_name
         self.__table_name = table_name
-        self.__max_batch_size = max_batch_size if max_batch_size else DEFAULT_MAX_BATCH_SIZE
-        self.__min_common_dimensions = min_common_dimensions if min_common_dimensions else DEFAULT_MIN_COMMON_DIMENSIONS
-
+        
     def does_database_exist(
         self,
         database_name: str = None,
@@ -62,6 +58,8 @@ class TimestreamLoader(TimestreamReader):
         source: str = None,
         upsert: bool = False,
         ignore_parse_error: bool = True,
+        max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
+        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
 
     ) -> dict:
         '''
@@ -74,7 +72,9 @@ class TimestreamLoader(TimestreamReader):
             source,
             upsert,
             ignore_parse_error,
-            False
+            False,
+            max_batch_size,
+            min_common_dimensions
         ).to_dict()
 
     def load_preview(
@@ -83,7 +83,9 @@ class TimestreamLoader(TimestreamReader):
         capture_time: datetime,
         source: str = None,
         upsert: bool = False,
-        ignore_parse_error: bool = True
+        ignore_parse_error: bool = True,
+        max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
+        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
     ) -> dict:
         '''
         Performs a dry run of a Timestream load, including validating the input values and parsing data
@@ -96,7 +98,9 @@ class TimestreamLoader(TimestreamReader):
             source,
             upsert,
             ignore_parse_error,
-            True
+            True,
+            max_batch_size,
+            min_common_dimensions
         ).to_dict()
 
     def __load(
@@ -106,7 +110,9 @@ class TimestreamLoader(TimestreamReader):
         source: str = None,
         upsert: bool = False,
         ignore_parse_error: bool = True,
-        preview: bool = False
+        preview: bool = False,
+        max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
+        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
     ) -> TimestreamLoadResult:
         self._logger.info(f'Loading data with {len(data)} elements')
 
@@ -117,11 +123,11 @@ class TimestreamLoader(TimestreamReader):
 
         # Batch the accepted records by common dimensions
         self._logger.info('starting batching...')
-        self._logger.info(f"BATCH {self.__max_batch_size} MIN {self.__min_common_dimensions}")
+        self._logger.info(f"BATCH {max_batch_size} MIN {min_common_dimensions}")
         batches = batch_records(
             result.accepted_records,
-            max_batch_size=self.__max_batch_size,
-            min_common_dimensions=self.__min_common_dimensions
+            max_batch_size=max_batch_size,
+            min_common_dimensions=min_common_dimensions
         )
         assert isinstance(batches, list) and len(batches) > 0, 'Batches must be a non-empty list'
         assert all(len(b.records) > 0 for b in batches), "Not all batches have records (shouldn't be possible)"
